API
===
*pyGPCCA* can be imported as::

  import pygpcca as gp

.. module::pygpcca
.. currentmodule::pygpcca

Functions
---------
.. autosummary::
    :toctree: api

    pygpcca.stationary_distribution
    pygpcca.gpcca_coarsegrain

Classes
-------
.. autosummary::
    :toctree: api

    pygpcca.GPCCA
